/// <reference types="node" />
import * as web3 from '@solana/web3.js';
import * as beet from '@metaplex-foundation/beet';
import { MarketState } from '../types/MarketState';
import { GatingConfig } from '../types/GatingConfig';
export declare type MarketArgs = {
    store: web3.PublicKey;
    sellingResource: web3.PublicKey;
    treasuryMint: web3.PublicKey;
    treasuryHolder: web3.PublicKey;
    treasuryOwner: web3.PublicKey;
    owner: web3.PublicKey;
    name: string;
    description: string;
    mutable: boolean;
    price: beet.bignum;
    piecesInOneWallet: beet.COption<beet.bignum>;
    startDate: beet.bignum;
    endDate: beet.COption<beet.bignum>;
    state: MarketState;
    fundsCollected: beet.bignum;
    gatekeeper: beet.COption<GatingConfig>;
};
export declare class Market implements MarketArgs {
    readonly store: web3.PublicKey;
    readonly sellingResource: web3.PublicKey;
    readonly treasuryMint: web3.PublicKey;
    readonly treasuryHolder: web3.PublicKey;
    readonly treasuryOwner: web3.PublicKey;
    readonly owner: web3.PublicKey;
    readonly name: string;
    readonly description: string;
    readonly mutable: boolean;
    readonly price: beet.bignum;
    readonly piecesInOneWallet: beet.COption<beet.bignum>;
    readonly startDate: beet.bignum;
    readonly endDate: beet.COption<beet.bignum>;
    readonly state: MarketState;
    readonly fundsCollected: beet.bignum;
    readonly gatekeeper: beet.COption<GatingConfig>;
    private constructor();
    static fromArgs(args: MarketArgs): Market;
    static fromAccountInfo(accountInfo: web3.AccountInfo<Buffer>, offset?: number): [Market, number];
    static fromAccountAddress(connection: web3.Connection, address: web3.PublicKey): Promise<Market>;
    static deserialize(buf: Buffer, offset?: number): [Market, number];
    serialize(): [Buffer, number];
    static byteSize(args: MarketArgs): number;
    static getMinimumBalanceForRentExemption(args: MarketArgs, connection: web3.Connection, commitment?: web3.Commitment): Promise<number>;
    pretty(): {
        store: string;
        sellingResource: string;
        treasuryMint: string;
        treasuryHolder: string;
        treasuryOwner: string;
        owner: string;
        name: string;
        description: string;
        mutable: boolean;
        price: beet.bignum;
        piecesInOneWallet: beet.COption<beet.bignum>;
        startDate: beet.bignum;
        endDate: beet.COption<beet.bignum>;
        state: string;
        fundsCollected: beet.bignum;
        gatekeeper: beet.COption<GatingConfig>;
    };
}
export declare const marketBeet: beet.FixableBeetStruct<Market, MarketArgs & {
    accountDiscriminator: number[];
}>;
