/// <reference types="node" />
import * as web3 from '@solana/web3.js';
import * as beet from '@metaplex-foundation/beet';
import { SellingResourceState } from '../types/SellingResourceState';
export declare type SellingResourceArgs = {
    store: web3.PublicKey;
    owner: web3.PublicKey;
    resource: web3.PublicKey;
    vault: web3.PublicKey;
    vaultOwner: web3.PublicKey;
    supply: beet.bignum;
    maxSupply: beet.COption<beet.bignum>;
    state: SellingResourceState;
};
export declare class SellingResource implements SellingResourceArgs {
    readonly store: web3.PublicKey;
    readonly owner: web3.PublicKey;
    readonly resource: web3.PublicKey;
    readonly vault: web3.PublicKey;
    readonly vaultOwner: web3.PublicKey;
    readonly supply: beet.bignum;
    readonly maxSupply: beet.COption<beet.bignum>;
    readonly state: SellingResourceState;
    private constructor();
    static fromArgs(args: SellingResourceArgs): SellingResource;
    static fromAccountInfo(accountInfo: web3.AccountInfo<Buffer>, offset?: number): [SellingResource, number];
    static fromAccountAddress(connection: web3.Connection, address: web3.PublicKey): Promise<SellingResource>;
    static deserialize(buf: Buffer, offset?: number): [SellingResource, number];
    serialize(): [Buffer, number];
    static byteSize(args: SellingResourceArgs): number;
    static getMinimumBalanceForRentExemption(args: SellingResourceArgs, connection: web3.Connection, commitment?: web3.Commitment): Promise<number>;
    pretty(): {
        store: string;
        owner: string;
        resource: string;
        vault: string;
        vaultOwner: string;
        supply: beet.bignum;
        maxSupply: beet.COption<beet.bignum>;
        state: string;
    };
}
export declare const sellingResourceBeet: beet.FixableBeetStruct<SellingResource, SellingResourceArgs & {
    accountDiscriminator: number[];
}>;
