/// <reference types="node" />
import * as web3 from '@solana/web3.js';
import * as beet from '@metaplex-foundation/beet';
export declare type TradeHistoryArgs = {
    market: web3.PublicKey;
    wallet: web3.PublicKey;
    alreadyBought: beet.bignum;
};
export declare class TradeHistory implements TradeHistoryArgs {
    readonly market: web3.PublicKey;
    readonly wallet: web3.PublicKey;
    readonly alreadyBought: beet.bignum;
    private constructor();
    static fromArgs(args: TradeHistoryArgs): TradeHistory;
    static fromAccountInfo(accountInfo: web3.AccountInfo<Buffer>, offset?: number): [TradeHistory, number];
    static fromAccountAddress(connection: web3.Connection, address: web3.PublicKey): Promise<TradeHistory>;
    static deserialize(buf: Buffer, offset?: number): [TradeHistory, number];
    serialize(): [Buffer, number];
    static get byteSize(): number;
    static getMinimumBalanceForRentExemption(connection: web3.Connection, commitment?: web3.Commitment): Promise<number>;
    static hasCorrectByteSize(buf: Buffer, offset?: number): boolean;
    pretty(): {
        market: string;
        wallet: string;
        alreadyBought: beet.bignum;
    };
}
export declare const tradeHistoryBeet: beet.BeetStruct<TradeHistory, TradeHistoryArgs & {
    accountDiscriminator: number[];
}>;
