"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateMembershipToken = exports.findPrimaryMetadataCreatorsAddress = exports.findPayoutTicketAddress = exports.findTradeHistoryAddress = exports.findTreasuryOwnerAddress = exports.findVaultOwnerAddress = void 0;
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const web3_js_1 = require("@solana/web3.js");
const generated_1 = require("../generated");
const assert_1 = require("assert");
const VAULT_OWNER_PREFIX = 'mt_vault';
const HISTORY_PREFIX = 'history';
const PAYOUT_TICKET_PREFIX = 'payout_ticket';
const HOLDER_PREFIX = 'holder';
const PRIMARY_METADATA_CREATORS_PREFIX = 'primary_creators';
const findVaultOwnerAddress = (mint, store) => web3_js_1.PublicKey.findProgramAddress([Buffer.from(VAULT_OWNER_PREFIX), mint.toBuffer(), store.toBuffer()], generated_1.PROGRAM_ID);
exports.findVaultOwnerAddress = findVaultOwnerAddress;
const findTreasuryOwnerAddress = (treasuryMint, sellingResource) => web3_js_1.PublicKey.findProgramAddress([Buffer.from(HOLDER_PREFIX), treasuryMint.toBuffer(), sellingResource.toBuffer()], generated_1.PROGRAM_ID);
exports.findTreasuryOwnerAddress = findTreasuryOwnerAddress;
const findTradeHistoryAddress = (wallet, market) => web3_js_1.PublicKey.findProgramAddress([Buffer.from(HISTORY_PREFIX), wallet.toBuffer(), market.toBuffer()], generated_1.PROGRAM_ID);
exports.findTradeHistoryAddress = findTradeHistoryAddress;
const findPayoutTicketAddress = (market, funder) => {
    return web3_js_1.PublicKey.findProgramAddress([Buffer.from(PAYOUT_TICKET_PREFIX), market.toBuffer(), funder.toBuffer()], generated_1.PROGRAM_ID);
};
exports.findPayoutTicketAddress = findPayoutTicketAddress;
const findPrimaryMetadataCreatorsAddress = (metadata) => web3_js_1.PublicKey.findProgramAddress([Buffer.from(PRIMARY_METADATA_CREATORS_PREFIX), metadata.toBuffer()], generated_1.PROGRAM_ID);
exports.findPrimaryMetadataCreatorsAddress = findPrimaryMetadataCreatorsAddress;
const validateMembershipToken = async (connection, me, ta) => {
    var _a;
    (0, assert_1.strict)(ta.data != null, 'token account data cannot be null');
    const edition = (await mpl_token_metadata_1.deprecated.Metadata.getEdition(connection, ta.data.mint));
    return ((_a = edition === null || edition === void 0 ? void 0 : edition.data) === null || _a === void 0 ? void 0 : _a.parent) === me;
};
exports.validateMembershipToken = validateMembershipToken;
//# sourceMappingURL=index.js.map