"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMarket = void 0;
const amman_1 = require("@metaplex-foundation/amman");
const web3_js_1 = require("@solana/web3.js");
const transactions_1 = require("../transactions");
const utils_1 = require("../utils");
const utils_2 = require("../../src/utils");
const instructions_1 = require("../../src/generated/instructions");
const createMarket = async ({ test, transactionHandler, payer, connection, store, sellingResource, treasuryMint, collectionMint, params, }) => {
    const [treasuryOwner, treasuryOwnerBump] = await (0, utils_2.findTreasuryOwnerAddress)(treasuryMint, sellingResource);
    (0, utils_1.logDebug)(`treasuryOwner: ${treasuryOwner.toBase58()}`);
    const { tokenAccount: treasuryHolder, createTokenTx } = await (0, transactions_1.createTokenAccount)({
        payer: payer.publicKey,
        connection,
        mint: treasuryMint,
        owner: treasuryOwner,
    });
    const createVaultRes = await transactionHandler.sendAndConfirmTransaction(createTokenTx, [treasuryHolder], amman_1.defaultSendOptions);
    (0, utils_1.logDebug)(`treasuryHolder: ${treasuryHolder.publicKey}`);
    (0, amman_1.assertConfirmedTransaction)(test, createVaultRes.txConfirmed);
    const market = web3_js_1.Keypair.generate();
    const instruction = (0, instructions_1.createCreateMarketInstruction)({
        market: market.publicKey,
        store,
        sellingResourceOwner: payer.publicKey,
        sellingResource,
        mint: treasuryMint,
        treasuryHolder: treasuryHolder.publicKey,
        owner: treasuryOwner,
        collectionMint,
    }, {
        treasuryOwnerBump,
        ...params,
    });
    const marketTx = await (0, utils_1.createAndSignTransaction)(connection, payer, [instruction], [market]);
    const marketRes = await transactionHandler.sendAndConfirmTransaction(marketTx, [market], amman_1.defaultSendOptions);
    (0, utils_1.logDebug)(`market: ${market.publicKey}`);
    (0, amman_1.assertConfirmedTransaction)(test, marketRes.txConfirmed);
    return { market, treasuryHolder, treasuryOwnerBump, treasuryOwner };
};
exports.createMarket = createMarket;
//# sourceMappingURL=createMarket.js.map