"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initSellingResource = void 0;
const amman_1 = require("@metaplex-foundation/amman");
const web3_js_1 = require("@solana/web3.js");
const utils_1 = require("../../src/utils");
const utils_2 = require("../utils");
const createTokenAccount_1 = require("../transactions/createTokenAccount");
const mintNft_1 = require("./mintNft");
const instructions_1 = require("../../src/generated/instructions");
const transactions_1 = require("../transactions");
const initSellingResource = async ({ test, transactionHandler, payer, connection, store, maxSupply, }) => {
    const secondaryCreator = {
        address: payer.publicKey,
        share: 100,
        verified: true,
    };
    const { edition: masterEdition, editionBump: masterEditionBump, tokenAccount: resourceToken, mint: resourceMint, metadata, } = await (0, mintNft_1.mintNFT)({
        transactionHandler,
        payer,
        connection,
        creators: [secondaryCreator],
    });
    const [vaultOwner, vaultOwnerBump] = await (0, utils_1.findVaultOwnerAddress)(resourceMint.publicKey, store);
    const { tokenAccount: vault, createTokenTx } = await (0, createTokenAccount_1.createTokenAccount)({
        payer: payer.publicKey,
        mint: resourceMint.publicKey,
        connection,
        owner: vaultOwner,
    });
    const createVaultRes = await transactionHandler.sendAndConfirmTransaction(createTokenTx, [vault], amman_1.defaultSendOptions);
    (0, amman_1.assertConfirmedTransaction)(test, createVaultRes.txConfirmed);
    const sellingResource = web3_js_1.Keypair.generate();
    const initSellingResourceInstruction = (0, instructions_1.createInitSellingResourceInstruction)({
        store,
        admin: payer.publicKey,
        sellingResource: sellingResource.publicKey,
        sellingResourceOwner: payer.publicKey,
        metadata,
        masterEdition,
        resourceMint: resourceMint.publicKey,
        resourceToken: resourceToken.publicKey,
        vault: vault.publicKey,
        owner: vaultOwner,
    }, {
        masterEditionBump,
        vaultOwnerBump,
        maxSupply,
    });
    const primaryCreator = {
        address: payer.publicKey,
        share: 100,
        verified: false,
    };
    const { savePrimaryMetadataCreatorsInstruction, primaryMetadataCreators } = await (0, transactions_1.createSavePrimaryMetadataCreators)({
        transactionHandler,
        payer,
        connection,
        metadata,
        creators: [primaryCreator],
    });
    (0, utils_2.logDebug)(`primary metadata creators ${primaryMetadataCreators}`);
    const initSellingResourceTx = await (0, utils_2.createAndSignTransaction)(connection, payer, [initSellingResourceInstruction, savePrimaryMetadataCreatorsInstruction], [sellingResource]);
    const initSellingResourceRes = await transactionHandler.sendAndConfirmTransaction(initSellingResourceTx, [sellingResource], amman_1.defaultSendOptions);
    (0, utils_2.logDebug)(`selling-resource: ${sellingResource.publicKey}`);
    (0, amman_1.assertConfirmedTransaction)(test, initSellingResourceRes.txConfirmed);
    return {
        sellingResource,
        vault,
        vaultOwner,
        vaultOwnerBump,
        resourceMint,
        metadata,
        primaryMetadataCreators: [primaryMetadataCreators],
    };
};
exports.initSellingResource = initSellingResource;
//# sourceMappingURL=initSellingResource.js.map