"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mintNFT = void 0;
const web3_js_1 = require("@solana/web3.js");
const amman_1 = require("@metaplex-foundation/amman");
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const spl_token_1 = require("@solana/spl-token");
const assert_1 = require("assert");
const createTokenAccount_1 = require("../transactions/createTokenAccount");
const createMintAccount_1 = require("./createMintAccount");
const URI = 'https://arweave.net/Rmg4pcIv-0FQ7M7X838p2r592Q4NU63Fj7o7XsvBHEE';
const NAME = 'test';
const SYMBOL = 'sym';
const SELLER_FEE_BASIS_POINTS = 10;
async function mintNFT({ transactionHandler, payer, connection, creators, collectionMint, maxSupply = 100, }) {
    const { mint, createMintTx } = await createMintAccount_1.CreateMint.createMintAccount(connection, payer.publicKey);
    const mintRes = await transactionHandler.sendAndConfirmTransaction(createMintTx, [mint], amman_1.defaultSendOptions);
    (0, amman_1.assertConfirmedTransaction)(assert_1.strict, mintRes.txConfirmed);
    const { tokenAccount, createTokenTx } = await (0, createTokenAccount_1.createTokenAccount)({
        payer: payer.publicKey,
        mint: mint.publicKey,
        connection,
    });
    createTokenTx.add((0, spl_token_1.createMintToInstruction)(mint.publicKey, tokenAccount.publicKey, payer.publicKey, 1));
    const data = {
        uri: URI,
        name: NAME,
        symbol: SYMBOL,
        sellerFeeBasisPoints: SELLER_FEE_BASIS_POINTS,
        creators: creators !== null && creators !== void 0 ? creators : null,
        collection: collectionMint
            ? {
                key: collectionMint,
                verified: false,
            }
            : null,
        uses: null,
    };
    const metadata = await mpl_token_metadata_1.deprecated.Metadata.getPDA(mint.publicKey);
    const createMetadataInstruction = (0, mpl_token_metadata_1.createCreateMetadataAccountV2Instruction)({
        metadata,
        mint: mint.publicKey,
        updateAuthority: payer.publicKey,
        mintAuthority: payer.publicKey,
        payer: payer.publicKey,
    }, { createMetadataAccountArgsV2: { isMutable: true, data } });
    createTokenTx.add(createMetadataInstruction);
    const [edition, editionBump] = await web3_js_1.PublicKey.findProgramAddress([
        Buffer.from(mpl_token_metadata_1.deprecated.MetadataProgram.PREFIX),
        mpl_token_metadata_1.PROGRAM_ID.toBuffer(),
        new web3_js_1.PublicKey(mint.publicKey).toBuffer(),
        Buffer.from(mpl_token_metadata_1.deprecated.MasterEdition.EDITION_PREFIX),
    ], mpl_token_metadata_1.PROGRAM_ID);
    const masterEditionInstruction = (0, mpl_token_metadata_1.createCreateMasterEditionV3Instruction)({
        edition,
        metadata,
        updateAuthority: payer.publicKey,
        mint: mint.publicKey,
        mintAuthority: payer.publicKey,
        payer: payer.publicKey,
    }, {
        createMasterEditionArgs: { maxSupply },
    });
    createTokenTx.add(masterEditionInstruction);
    const res = await transactionHandler.sendAndConfirmTransaction(createTokenTx, [tokenAccount], amman_1.defaultSendOptions);
    (0, amman_1.assertConfirmedTransaction)(assert_1.strict, res.txConfirmed);
    return { tokenAccount, edition, editionBump, mint, metadata };
}
exports.mintNFT = mintNFT;
//# sourceMappingURL=mintNft.js.map