"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const bn_js_1 = __importDefault(require("bn.js"));
const tape_1 = __importDefault(require("tape"));
const amman_1 = require("@metaplex-foundation/amman");
const mpl_token_metadata_1 = require("@metaplex-foundation/mpl-token-metadata");
const utils_1 = require("../src/utils");
const transactions_1 = require("./transactions");
const utils_2 = require("./utils");
const actions_1 = require("./actions");
const verifyCollection_1 = require("./actions/verifyCollection");
(0, utils_2.killStuckProcess)();
(0, tape_1.default)('buy: successful purchase without gating', async (t) => {
    const { payer, connection, transactionHandler } = await (0, actions_1.createPrerequisites)();
    const store = await (0, actions_1.createStore)({
        test: t,
        transactionHandler,
        payer,
        connection,
        params: {
            name: 'Store',
            description: 'Description',
        },
    });
    const { sellingResource, vault, vaultOwner, vaultOwnerBump, resourceMint } = await (0, actions_1.initSellingResource)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        maxSupply: 100,
    });
    const { mint: treasuryMint, tokenAccount: userTokenAcc } = await (0, actions_1.mintNFT)({
        transactionHandler,
        payer,
        connection,
    });
    const startDate = Math.round(Date.now() / 1000);
    const params = {
        name: 'Market',
        description: '',
        startDate,
        endDate: startDate + 5 * 20,
        mutable: true,
        price: 0.001,
        piecesInOneWallet: 1,
        gatingConfig: null,
    };
    const { market, treasuryHolder } = await (0, actions_1.createMarket)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        sellingResource: sellingResource.publicKey,
        treasuryMint: treasuryMint.publicKey,
        params,
    });
    const [tradeHistory, tradeHistoryBump] = await (0, utils_1.findTradeHistoryAddress)(payer.publicKey, market.publicKey);
    const { mint: newMint, mintAta } = await (0, actions_1.mintTokenToAccount)({
        connection,
        payer: payer.publicKey,
        transactionHandler,
    });
    (0, utils_2.logDebug)('new mint', newMint.publicKey.toBase58());
    const newMintEdition = await mpl_token_metadata_1.deprecated.Edition.getPDA(newMint.publicKey);
    const newMintMetadata = await mpl_token_metadata_1.deprecated.Metadata.getPDA(newMint.publicKey);
    const resourceMintMasterEdition = await mpl_token_metadata_1.deprecated.Edition.getPDA(resourceMint.publicKey);
    const resourceMintMetadata = await mpl_token_metadata_1.deprecated.Metadata.getPDA(resourceMint.publicKey);
    const resourceMintEditionMarker = await mpl_token_metadata_1.deprecated.EditionMarker.getPDA(resourceMint.publicKey, new bn_js_1.default(1));
    await (0, utils_2.sleep)(1000);
    const { tx: buyTx } = await (0, transactions_1.createBuyTransaction)({
        connection,
        buyer: payer.publicKey,
        userTokenAccount: userTokenAcc.publicKey,
        resourceMintMetadata,
        resourceMintEditionMarker,
        resourceMintMasterEdition,
        sellingResource: sellingResource.publicKey,
        market: market.publicKey,
        marketTreasuryHolder: treasuryHolder.publicKey,
        vaultOwner,
        tradeHistory,
        tradeHistoryBump,
        vault: vault.publicKey,
        vaultOwnerBump,
        newMint: newMint.publicKey,
        newMintEdition,
        newMintMetadata,
        newTokenAccount: mintAta.publicKey,
    });
    const buyRes = await transactionHandler.sendAndConfirmTransaction(buyTx, [payer], amman_1.defaultSendOptions);
    (0, utils_2.logDebug)('buy:: successful purchase');
    (0, amman_1.assertConfirmedTransaction)(t, buyRes.txConfirmed);
});
(0, tape_1.default)('buy: successful purchase with gating', async (t) => {
    const { payer, connection, transactionHandler } = await (0, actions_1.createPrerequisites)();
    const store = await (0, actions_1.createStore)({
        test: t,
        transactionHandler,
        payer,
        connection,
        params: {
            name: 'Store',
            description: 'Description',
        },
    });
    const { mint: collectionMint, metadata: collectionMetadata, edition: collectionMasterEditionAccount, } = await (0, actions_1.mintNFT)({
        transactionHandler,
        payer,
        connection,
        maxSupply: 0,
    });
    const { sellingResource, vault, vaultOwner, vaultOwnerBump, resourceMint } = await (0, actions_1.initSellingResource)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        maxSupply: 100,
    });
    const { mint: treasuryMint, tokenAccount: userTokenAcc } = await (0, actions_1.mintNFT)({
        transactionHandler,
        payer,
        connection,
    });
    const startDate = Math.round(Date.now() / 1000);
    const params = {
        name: 'Market',
        description: '',
        startDate,
        endDate: startDate + 5 * 20,
        mutable: true,
        price: 0.001,
        piecesInOneWallet: 1,
        gatingConfig: {
            collection: collectionMint.publicKey,
            expireOnUse: true,
            gatingTime: null,
        },
    };
    const { market, treasuryHolder } = await (0, actions_1.createMarket)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        sellingResource: sellingResource.publicKey,
        treasuryMint: treasuryMint.publicKey,
        collectionMint: collectionMint.publicKey,
        params,
    });
    const [tradeHistory, tradeHistoryBump] = await (0, utils_1.findTradeHistoryAddress)(payer.publicKey, market.publicKey);
    const { mint: newMint, mintAta } = await (0, actions_1.mintTokenToAccount)({
        connection,
        payer: payer.publicKey,
        transactionHandler,
    });
    (0, utils_2.logDebug)('new mint', newMint.publicKey.toBase58());
    const newMintEdition = await mpl_token_metadata_1.deprecated.Edition.getPDA(newMint.publicKey);
    const newMintMetadata = await mpl_token_metadata_1.deprecated.Metadata.getPDA(newMint.publicKey);
    const resourceMintMasterEdition = await mpl_token_metadata_1.deprecated.Edition.getPDA(resourceMint.publicKey);
    const resourceMintMetadata = await mpl_token_metadata_1.deprecated.Metadata.getPDA(resourceMint.publicKey);
    const resourceMintEditionMarker = await mpl_token_metadata_1.deprecated.EditionMarker.getPDA(resourceMint.publicKey, new bn_js_1.default(1));
    const { mint: userCollectionTokenMint, tokenAccount: userCollectionTokenAcc, metadata: userCollectionMetadata, } = await (0, actions_1.mintNFT)({
        transactionHandler,
        payer,
        connection,
        collectionMint: collectionMint.publicKey,
    });
    await (0, verifyCollection_1.verifyCollection)({
        transactionHandler,
        connection,
        payer,
        metadata: userCollectionMetadata,
        collectionAuthority: payer.publicKey,
        collection: collectionMetadata,
        collectionMint: collectionMint.publicKey,
        collectionMasterEditionAccount,
    });
    await (0, utils_2.sleep)(1000);
    const { tx: buyTx } = await (0, transactions_1.createBuyTransaction)({
        connection,
        buyer: payer.publicKey,
        userTokenAccount: userTokenAcc.publicKey,
        resourceMintMetadata,
        resourceMintEditionMarker,
        resourceMintMasterEdition,
        sellingResource: sellingResource.publicKey,
        market: market.publicKey,
        marketTreasuryHolder: treasuryHolder.publicKey,
        vaultOwner,
        tradeHistory,
        tradeHistoryBump,
        vault: vault.publicKey,
        vaultOwnerBump,
        newMint: newMint.publicKey,
        newMintEdition,
        newMintMetadata,
        newTokenAccount: mintAta.publicKey,
        additionalKeys: [
            {
                pubkey: userCollectionTokenAcc.publicKey,
                isSigner: false,
                isWritable: true,
            },
            {
                pubkey: userCollectionTokenMint.publicKey,
                isSigner: false,
                isWritable: true,
            },
            {
                pubkey: userCollectionMetadata,
                isSigner: false,
                isWritable: false,
            },
        ],
    });
    const buyRes = await transactionHandler.sendAndConfirmTransaction(buyTx, [payer], amman_1.defaultSendOptions);
    (0, utils_2.logDebug)('buy:: successful purchase');
    (0, amman_1.assertConfirmedTransaction)(t, buyRes.txConfirmed);
});
(0, tape_1.default)('buy: unsuccessful purchase with gating', async (t) => {
    const { payer, connection, transactionHandler } = await (0, actions_1.createPrerequisites)();
    const store = await (0, actions_1.createStore)({
        test: t,
        transactionHandler,
        payer,
        connection,
        params: {
            name: 'Store',
            description: 'Description',
        },
    });
    const { mint: collectionMint } = await (0, actions_1.mintNFT)({
        transactionHandler,
        payer,
        connection,
        maxSupply: 0,
    });
    const { sellingResource, vault, vaultOwner, vaultOwnerBump, resourceMint } = await (0, actions_1.initSellingResource)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        maxSupply: 100,
    });
    const { mint: treasuryMint, tokenAccount: userTokenAcc } = await (0, actions_1.mintNFT)({
        transactionHandler,
        payer,
        connection,
    });
    const startDate = Math.round(Date.now() / 1000);
    const params = {
        name: 'Market',
        description: '',
        startDate,
        endDate: startDate + 5 * 20,
        mutable: true,
        price: 0.001,
        piecesInOneWallet: 1,
        gatingConfig: {
            collection: collectionMint.publicKey,
            expireOnUse: true,
            gatingTime: null,
        },
    };
    const { market, treasuryHolder } = await (0, actions_1.createMarket)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        sellingResource: sellingResource.publicKey,
        treasuryMint: treasuryMint.publicKey,
        collectionMint: collectionMint.publicKey,
        params,
    });
    const [tradeHistory, tradeHistoryBump] = await (0, utils_1.findTradeHistoryAddress)(payer.publicKey, market.publicKey);
    const { mint: newMint, mintAta } = await (0, actions_1.mintTokenToAccount)({
        connection,
        payer: payer.publicKey,
        transactionHandler,
    });
    (0, utils_2.logDebug)('new mint', newMint.publicKey.toBase58());
    const newMintEdition = await mpl_token_metadata_1.deprecated.Edition.getPDA(newMint.publicKey);
    const newMintMetadata = await mpl_token_metadata_1.deprecated.Metadata.getPDA(newMint.publicKey);
    const resourceMintMasterEdition = await mpl_token_metadata_1.deprecated.Edition.getPDA(resourceMint.publicKey);
    const resourceMintMetadata = await mpl_token_metadata_1.deprecated.Metadata.getPDA(resourceMint.publicKey);
    const resourceMintEditionMarker = await mpl_token_metadata_1.deprecated.EditionMarker.getPDA(resourceMint.publicKey, new bn_js_1.default(1));
    await (0, utils_2.sleep)(1000);
    const { tx: buyTx } = await (0, transactions_1.createBuyTransaction)({
        connection,
        buyer: payer.publicKey,
        userTokenAccount: userTokenAcc.publicKey,
        resourceMintMetadata,
        resourceMintEditionMarker,
        resourceMintMasterEdition,
        sellingResource: sellingResource.publicKey,
        market: market.publicKey,
        marketTreasuryHolder: treasuryHolder.publicKey,
        vaultOwner,
        tradeHistory,
        tradeHistoryBump,
        vault: vault.publicKey,
        vaultOwnerBump,
        newMint: newMint.publicKey,
        newMintEdition,
        newMintMetadata,
        newTokenAccount: mintAta.publicKey,
    });
    try {
        await transactionHandler.sendAndConfirmTransaction(buyTx, [payer], amman_1.defaultSendOptions);
    }
    catch (err) {
        (0, amman_1.assertError)(t, err, [/GatingTokenMissing/i, /Gating token is missing/i]);
    }
});
//# sourceMappingURL=buy.test.js.map