"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createWithdrawTransaction = void 0;
const spl_token_1 = require("@solana/spl-token");
const web3_js_1 = require("@solana/web3.js");
const utils_1 = require("../utils");
const instructions_1 = require("../../src/generated/instructions");
const createWithdrawTransaction = async ({ payer, connection, market, payoutTicket, destination, treasuryMint, treasuryHolder, metadata, sellingResource, treasuryOwnerBump, payoutTicketBump, treasuryOwner, primaryMetadataCreators, }) => {
    const instruction = await (0, instructions_1.createWithdrawInstruction)({
        market,
        sellingResource,
        metadata,
        treasuryHolder,
        treasuryMint,
        owner: treasuryOwner,
        destination,
        funder: payer.publicKey,
        payer: payer.publicKey,
        payoutTicket: payoutTicket,
        associatedTokenProgram: spl_token_1.ASSOCIATED_TOKEN_PROGRAM_ID,
        primaryMetadataCreators: primaryMetadataCreators,
        clock: web3_js_1.SYSVAR_CLOCK_PUBKEY,
    }, {
        treasuryOwnerBump,
        payoutTicketBump,
    });
    const withdrawTx = await (0, utils_1.createAndSignTransaction)(connection, payer, [instruction], [payer]);
    return withdrawTx;
};
exports.createWithdrawTransaction = createWithdrawTransaction;
//# sourceMappingURL=withdraw.js.map